@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2012-2019 Oracle Corporation
+ * Copyright (C) 2012-2020 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -28,17 +28,8 @@
 
 #include <iprt/cdefs.h>
 
-#if 0
-/* enable this in case we include this in a dll*/
-# ifdef IN_VBOXCRHGSMI
-#  define VBOXDISPMPLOGGER_DECL(a_Type) DECLEXPORT(a_Type) RTCALL
-# else
-#  define VBOXDISPMPLOGGER_DECL(a_Type) DECLIMPORT(a_Type) RTCALL
-# endif
-#else
 /*enable this in case we include this in a static lib*/
 # define VBOXDISPMPLOGGER_DECL(a_Type) a_Type RTCALL
-#endif
 
 RT_C_DECLS_BEGIN
 
