@@ -43,6 +43,7 @@
 #define VBOXWDDM_CFG_LOG_UM_BACKDOOR 0x00000001
 #define VBOXWDDM_CFG_LOG_UM_DBGPRINT 0x00000002
 #define VBOXWDDM_CFG_STR_LOG_UM L"VBoxLogUm"
+#define VBOXWDDM_CFG_STR_RATE L"RefreshRate"
 
 #define VBOXWDDM_REG_DRV_FLAGS_NAME L"VBoxFlags"
 #define VBOXWDDM_REG_DRV_DISPFLAGS_PREFIX L"VBoxDispFlags"
@@ -62,6 +63,7 @@
 #define VBOXWDDM_REG_DISPLAYSETTINGS_ATTACH_DESKTOP L"Attach.ToDesktop"
 
 extern DWORD g_VBoxLogUm;
+extern DWORD g_RefreshRate;
 
 RT_C_DECLS_BEGIN
 NTSTATUS DriverEntry(IN PDRIVER_OBJECT DriverObject, IN PUNICODE_STRING RegistryPath);
