@@ -53,6 +53,8 @@
 #endif
 #include <VBox/log.h>
 
+#include <VBox/err.h>
+
 /* Default desktop state tracking */
 #include <Wtsapi32.h>
 
@@ -311,13 +313,22 @@ static int vboxTrayServicesStart(PVBOXSERVICEENV pEnv)
 
         if (RT_FAILURE(rc2))
         {
-            LogRel(("Failed to initialize service '%s', rc=%Rrc\n", pSvc->pDesc->pszName, rc2));
-            if (rc2 == VERR_NOT_SUPPORTED)
+            switch (rc2)
             {
-                LogRel(("Service '%s' is not supported on this system\n", pSvc->pDesc->pszName));
-                rc2 = VINF_SUCCESS;
+                case VERR_NOT_SUPPORTED:
+                    LogRel(("Service '%s' is not supported on this system\n", pSvc->pDesc->pszName));
+                    rc2 = VINF_SUCCESS; /* Keep going. */
+                    break;
+
+                case VERR_HGCM_SERVICE_NOT_FOUND:
+                    LogRel(("Service '%s' is not available on the host\n", pSvc->pDesc->pszName));
+                    rc2 = VINF_SUCCESS; /* Keep going. */
+                    break;
+
+                default:
+                    LogRel(("Failed to initialize service '%s', rc=%Rrc\n", pSvc->pDesc->pszName, rc2));
+                    break;
             }
-            /* Keep going. */
         }
         else
         {
@@ -555,9 +566,8 @@ static void vboxTrayLogHeaderFooter(PRTLOGGER pLoggerRelease, RTLOGPHASE enmPhas
  * Pass NULL for disabled logging.
  *
  * @return  IPRT status code.
- * @param   pszLogFile              Filename for log output.  Optional.
  */
-static int vboxTrayLogCreate(const char *pszLogFile)
+static int vboxTrayLogCreate(void)
 {
     /* Create release logger (stdout + file). */
     static const char * const s_apszGroups[] = VBOX_LOGGROUP_NAMES;
@@ -576,7 +586,7 @@ static int vboxTrayLogCreate(const char *pszLogFile)
 #endif
                            RT_ELEMENTS(s_apszGroups), s_apszGroups, UINT32_MAX, RTLOGDEST_STDOUT,
                            vboxTrayLogHeaderFooter, g_cHistory, g_uHistoryFileSize, g_uHistoryFileTime,
-                           RTErrInfoInitStatic(&ErrInfo), pszLogFile);
+                           RTErrInfoInitStatic(&ErrInfo), NULL /*pszFilenameFmt*/);
     if (RT_SUCCESS(rc))
     {
 #ifdef DEBUG
@@ -990,7 +1000,7 @@ int APIENTRY WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLi
 
     LogRel(("%s r%s\n", RTBldCfgVersion(), RTBldCfgRevisionStr()));
 
-    rc = vboxTrayLogCreate(NULL /* pszLogFile */);
+    rc = vboxTrayLogCreate();
     if (RT_SUCCESS(rc))
     {
         rc = VbglR3Init();
